@@ -1,3 +1,5 @@
+#define QT_FEATURE_version_tagging 1
+
 #define QT_FEATURE_shared 1
 
 #define QT_FEATURE_static -1
@@ -20,28 +22,20 @@
 
 #define QT_FEATURE_framework -1
 
-#define QT_FEATURE_cxx11 1
-
-#define QT_FEATURE_cxx14 1
-
-#define QT_FEATURE_cxx17 1
-
-#define QT_FEATURE_cxx1z 1
-
 #define QT_FEATURE_cxx20 -1
 
 #define QT_FEATURE_cxx2a -1
 
 #define QT_FEATURE_cxx2b -1
 
-#define QT_FEATURE_c99 1
-
-#define QT_FEATURE_c11 1
-
 #define QT_FEATURE_reduce_relocations -1
 
 #define QT_FEATURE_signaling_nan 1
 
+#define QT_FEATURE_wasm_simd128 -1
+
+#define QT_FEATURE_wasm_exceptions -1
+
 #define QT_FEATURE_zstd 1
 
 #define QT_FEATURE_thread 1
@@ -52,14 +46,23 @@
 
 #define QT_FEATURE_dbus 1
 
+#define QT_FEATURE_openssl_linked 1
 
-#define QT_VERSION_STR "6.4.2"
+#define QT_FEATURE_opensslv11 -1
+
+#define QT_FEATURE_opensslv30 1
+
+
+#define QT_VERSION_STR "6.8.1"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 4
+#define QT_VERSION_MINOR 8
 
-#define QT_VERSION_PATCH 2
+#define QT_VERSION_PATCH 1
+
+#define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
 #define QT_COMPILER_SUPPORTS_NEON 1
+#define QT_LINKED_OPENSSL
